==> mktcenter-service-2.1.5-dzp-20220525.081213-3-sources.jar: com/bizvane/mktcenterservice/rpc/ActivityPrizeServiceRpc.java <==
package com.bizvane.mktcenterservice.rpc;

import com.bizvane.mktcenterservice.models.po.MktActivityPrizeRecordPO;
import com.bizvane.mktcenterservice.models.vo.ActivityPrizeBO;
import com.bizvane.mktcenterservice.models.vo.ProbabilityVO;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.text.ParseException;
import java.util.List;
import java.util.Map;

/**
 * Created by agan on 2018/12/19.
 */
@FeignClient(value = "${feign.client.mktcenter.name}",path = "${feign.client.mktcenter.path}/activityPrizeRpc")
public interface ActivityPrizeServiceRpc {
    /**
     * 小程序获取中奖纪录 和中奖纪录轮播
     * @param po
     * @return
     */
    @RequestMapping("getPrizeRecordListRpc")
    ResponseData<List<MktActivityPrizeRecordPO>> getPrizeRecordListRpc(@RequestBody MktActivityPrizeRecordPO po);

    /**
     * 获取抽奖活动规则
     * @param
     * @return
     */
    @RequestMapping("selectPrizeList")
    ResponseData<ActivityPrizeBO> selectPrizeList(@RequestParam("activePriceCode") String activePriceCode);

    /**
     * 执行抽奖活动
     * @param activePriceCode
     * @return
     */

    @RequestMapping("executeActivityPrize")
    ResponseData<Map> executeActivityPrize(@RequestParam("activePriceCode") String activePriceCode, @RequestParam("memberCode") String memberCode);

    @RequestMapping("residueMemberNumber")
    public ResponseData<Map<String, Integer>> residueMemberNumber(ProbabilityVO vo) throws ParseException;
}

==> mktcenter-service-2.2.0-dzp-20220529.103203-1-sources.jar: com/bizvane/mktcenterservice/rpc/ActivityPrizeServiceRpc.java <==
package com.bizvane.mktcenterservice.rpc;

import com.bizvane.mktcenterservice.models.bo.MktActivityPrizeRecordBO;
import com.bizvane.mktcenterservice.models.po.MktActivityPrizeRecordPO;
import com.bizvane.mktcenterservice.models.vo.ActivityPrizeBO;
import com.bizvane.mktcenterservice.models.vo.ActivityPrizeRecordDetailBO;
import com.bizvane.mktcenterservice.models.vo.ProbabilityVO;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;

import java.text.ParseException;
import java.util.List;
import java.util.Map;

/**
 * Created by agan on 2018/12/19.
 */
@FeignClient(value = "${feign.client.mktcenter.name}",path = "${feign.client.mktcenter.path}/activityPrizeRpc")
public interface ActivityPrizeServiceRpc {
    /**
     * 小程序获取中奖纪录 和中奖纪录轮播
     * @param po
     * @return
     */
    @RequestMapping("getPrizeRecordListRpc")
    ResponseData<List<MktActivityPrizeRecordPO>> getPrizeRecordListRpc(@RequestBody MktActivityPrizeRecordPO po);

    /**
     * 小程序获取中奖纪录 和中奖纪录轮播-返回奖项图片
     * @param po
     * @return
     */
    @RequestMapping("getPrizeRecordListRpcNew")
    ResponseData<List<MktActivityPrizeRecordBO>> getPrizeRecordListRpcNew(@RequestBody MktActivityPrizeRecordPO po);

    /**
     * 获取抽奖活动规则
     * @param
     * @return
     */
    @RequestMapping("selectPrizeList")
    ResponseData<ActivityPrizeBO> selectPrizeList(@RequestParam("activePriceCode") String activePriceCode);

    /**
     * 执行抽奖活动
     * @param activePriceCode
     * @return
     */

    @RequestMapping("executeActivityPrize")
    ResponseData<Map> executeActivityPrize(@RequestParam("activePriceCode") String activePriceCode, @RequestParam("memberCode") String memberCode);

    @RequestMapping("residueMemberNumber")
    public ResponseData<Map<String, Integer>> residueMemberNumber(ProbabilityVO vo) throws ParseException;

    @RequestMapping("winningRecordDetail")
    ResponseData<ActivityPrizeRecordDetailBO> winningRecordDetail(@RequestBody MktActivityPrizeRecordPO po);
}
